<?php
/**
  Simplifies the use of less (lessPHP) 
*/

# get correct id for plugin
$thisfile = basename(__FILE__, ".php");

# register plugin
register_plugin(
	$thisfile, 
	'Less', 	
	'0.9.1', 		
	'Martin Vlcek',
	'http://mvlcek.bplaced.net', 
	'Easy use of Less to customize CSS',
	'',
	''  
);

/**
 * Compiles a less file to a css file, if the less file is newer or the parameters are changed ($multipleCSS = false).
 * Compiles a less file to a parameter specific css file, if the less file is newer ($multipleCSS = true). 
 * 
 * @param string $themeRelativeLessFile  the name of the less file, e.g. "default.less" or "css/default.less
 * @param array  $params                 an associative array with the parameters for the less file or null
 * @param bool   $multipleCSS            if true, than for each parameter set a new CSS file is compiled 
 */
function return_less_css($themeRelativeLessFile, $params=null, $multipleCSS=false) {
  global $SITEURL, $TEMPLATE;
  $lessFile = GSTHEMESPATH.$TEMPLATE."/".$themeRelativeLessFile;
  if ($params) {
    $paramStr = "";
    foreach ($params as $key => $value) {
      $paramStr .= $key."=".$value.",";
    }
    $hash = md5($paramStr);
  } else {
    $hash = 0;
  }
  $lessTime = filemtime($lessFile);
  if ($multipleCSS) {
    $cssFile = substr($lessFile,0,strrpos($lessFile,'.')).$hash.".css";
    $doCompile = !file_exists($cssFile) || filemtime($cssFile) <= $lessTime;
  } else {
    $cssFile = substr($lessFile,0,strrpos($lessFile,'.')).".css";
    $hashFile = substr($lessFile,0,strrpos($lessFile,'.')).".hash";
    $doCompile = !file_exists($hashFile) || !file_exists($cssFile) || file_get_contents($hashFile) != $hash || filemtime($cssFile) <= $lessTime;
  }
  if ($doCompile) {
    require_once(GSPLUGINPATH.'less/lessc.inc.php');
    $lessc = new lessc;
    if ($params) $lessc->setVariables($params);
    $lessc->compileFile($lessFile, $cssFile);  
    if (!$multipleCSS) file_put_contents($hashFile, $hash);
  }
  return trim($SITEURL."theme/".$TEMPLATE)."/".substr($themeRelativeLessFile,0,strrpos($themeRelativeLessFile,'.')).($multipleCSS ? $hash : '').".css";
}

/**
 * outputs the CSS file name, generated by return_less_css.
 */
function get_less_css($themeRelativeLessFile, $params=null, $multipleCSS=false) {
  echo return_less_css($themeRelativeLessFile, $params, $multipleCSS);
}
